==> spirv-tools-1%3A1.4.321.0-1-x86_64.pkg.tar.zst: usr/lib/cmake/SPIRV-Tools-tools/SPIRV-Tools-toolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "spirv-as" for configuration "Release"
set_property(TARGET spirv-as APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-as PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-as"
  )

list(APPEND _cmake_import_check_targets spirv-as )
list(APPEND _cmake_import_check_files_for_spirv-as "${_IMPORT_PREFIX}/bin/spirv-as" )

# Import target "spirv-dis" for configuration "Release"
set_property(TARGET spirv-dis APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-dis PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-dis"
  )

list(APPEND _cmake_import_check_targets spirv-dis )
list(APPEND _cmake_import_check_files_for_spirv-dis "${_IMPORT_PREFIX}/bin/spirv-dis" )

# Import target "spirv-val" for configuration "Release"
set_property(TARGET spirv-val APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-val PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-val"
  )

list(APPEND _cmake_import_check_targets spirv-val )
list(APPEND _cmake_import_check_files_for_spirv-val "${_IMPORT_PREFIX}/bin/spirv-val" )

# Import target "spirv-opt" for configuration "Release"
set_property(TARGET spirv-opt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-opt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-opt"
  )

list(APPEND _cmake_import_check_targets spirv-opt )
list(APPEND _cmake_import_check_files_for_spirv-opt "${_IMPORT_PREFIX}/bin/spirv-opt" )

# Import target "spirv-cfg" for configuration "Release"
set_property(TARGET spirv-cfg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-cfg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-cfg"
  )

list(APPEND _cmake_import_check_targets spirv-cfg )
list(APPEND _cmake_import_check_files_for_spirv-cfg "${_IMPORT_PREFIX}/bin/spirv-cfg" )

# Import target "spirv-link" for configuration "Release"
set_property(TARGET spirv-link APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-link PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-link"
  )

list(APPEND _cmake_import_check_targets spirv-link )
list(APPEND _cmake_import_check_files_for_spirv-link "${_IMPORT_PREFIX}/bin/spirv-link" )

# Import target "spirv-lint" for configuration "Release"
set_property(TARGET spirv-lint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-lint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-lint"
  )

list(APPEND _cmake_import_check_targets spirv-lint )
list(APPEND _cmake_import_check_files_for_spirv-lint "${_IMPORT_PREFIX}/bin/spirv-lint" )

# Import target "spirv-objdump" for configuration "Release"
set_property(TARGET spirv-objdump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-objdump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-objdump"
  )

list(APPEND _cmake_import_check_targets spirv-objdump )
list(APPEND _cmake_import_check_files_for_spirv-objdump "${_IMPORT_PREFIX}/bin/spirv-objdump" )

# Import target "spirv-reduce" for configuration "Release"
set_property(TARGET spirv-reduce APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-reduce PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-reduce"
  )

list(APPEND _cmake_import_check_targets spirv-reduce )
list(APPEND _cmake_import_check_files_for_spirv-reduce "${_IMPORT_PREFIX}/bin/spirv-reduce" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> spirv-tools-1%3A1.4.341.0-2-x86_64.pkg.tar.zst: usr/lib/cmake/SPIRV-Tools-tools/SPIRV-Tools-toolsTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "spirv-as" for configuration "Release"
set_property(TARGET spirv-as APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-as PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-as"
  )

list(APPEND _cmake_import_check_targets spirv-as )
list(APPEND _cmake_import_check_files_for_spirv-as "${_IMPORT_PREFIX}/bin/spirv-as" )

# Import target "spirv-dis" for configuration "Release"
set_property(TARGET spirv-dis APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-dis PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-dis"
  )

list(APPEND _cmake_import_check_targets spirv-dis )
list(APPEND _cmake_import_check_files_for_spirv-dis "${_IMPORT_PREFIX}/bin/spirv-dis" )

# Import target "spirv-val" for configuration "Release"
set_property(TARGET spirv-val APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-val PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-val"
  )

list(APPEND _cmake_import_check_targets spirv-val )
list(APPEND _cmake_import_check_files_for_spirv-val "${_IMPORT_PREFIX}/bin/spirv-val" )

# Import target "spirv-opt" for configuration "Release"
set_property(TARGET spirv-opt APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-opt PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-opt"
  )

list(APPEND _cmake_import_check_targets spirv-opt )
list(APPEND _cmake_import_check_files_for_spirv-opt "${_IMPORT_PREFIX}/bin/spirv-opt" )

# Import target "spirv-cfg" for configuration "Release"
set_property(TARGET spirv-cfg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-cfg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-cfg"
  )

list(APPEND _cmake_import_check_targets spirv-cfg )
list(APPEND _cmake_import_check_files_for_spirv-cfg "${_IMPORT_PREFIX}/bin/spirv-cfg" )

# Import target "spirv-link" for configuration "Release"
set_property(TARGET spirv-link APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-link PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-link"
  )

list(APPEND _cmake_import_check_targets spirv-link )
list(APPEND _cmake_import_check_files_for_spirv-link "${_IMPORT_PREFIX}/bin/spirv-link" )

# Import target "spirv-lint" for configuration "Release"
set_property(TARGET spirv-lint APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-lint PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-lint"
  )

list(APPEND _cmake_import_check_targets spirv-lint )
list(APPEND _cmake_import_check_files_for_spirv-lint "${_IMPORT_PREFIX}/bin/spirv-lint" )

# Import target "spirv-diff" for configuration "Release"
set_property(TARGET spirv-diff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-diff PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-diff"
  )

list(APPEND _cmake_import_check_targets spirv-diff )
list(APPEND _cmake_import_check_files_for_spirv-diff "${_IMPORT_PREFIX}/bin/spirv-diff" )

# Import target "spirv-objdump" for configuration "Release"
set_property(TARGET spirv-objdump APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-objdump PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-objdump"
  )

list(APPEND _cmake_import_check_targets spirv-objdump )
list(APPEND _cmake_import_check_files_for_spirv-objdump "${_IMPORT_PREFIX}/bin/spirv-objdump" )

# Import target "spirv-reduce" for configuration "Release"
set_property(TARGET spirv-reduce APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(spirv-reduce PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/bin/spirv-reduce"
  )

list(APPEND _cmake_import_check_targets spirv-reduce )
list(APPEND _cmake_import_check_files_for_spirv-reduce "${_IMPORT_PREFIX}/bin/spirv-reduce" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
